from django.conf import settings

# Define your default settings
DEFAULTS = {
    'AWS_ACCESS_KEY_ID': None,
    'AWS_SECRET_ACCESS_KEY': None,
    'AWS_S3_REGION_NAME': None,
    'AWS_STORAGE_BUCKET_NAME': None,
    'AWS_STORAGE_BASE_DIR': ''
}


# Function to get settings with defaults
def get_setting(setting_name):
    """
    Get a setting value from Django settings, or raise an error if not provided.
    """
    value = getattr(settings, setting_name, DEFAULTS[setting_name])
    if value is None:
        raise ValueError(f"Missing required setting: {setting_name}")
    return value


# Create properties for easy access to settings
AWS_ACCESS_KEY_ID = get_setting('AWS_ACCESS_KEY_ID')
AWS_SECRET_ACCESS_KEY = get_setting('AWS_SECRET_ACCESS_KEY')
AWS_S3_REGION_NAME = get_setting('AWS_S3_REGION_NAME')
AWS_STORAGE_BUCKET_NAME = get_setting('AWS_STORAGE_BUCKET_NAME')
AWS_STORAGE_BASE_DIR = get_setting('AWS_STORAGE_BASE_DIR')


from django.urls import path
from . import views

urlpatterns = [
    path('browse', views.list_s3_files, name='s3_files'),
    path('delete/<path:delete_path>', views.delete_file, name='delete_s3_file'),
]


import setuptools
from setuptools import setup, find_packages

setup(
    name             = 'django-s3files',
    version          = '0.0.2',
    description      = 'Django AWS S3 File Manager enables you to manage files directly from the Django admin '
                       'interface, allowing you to read, upload, and delete files without directly accessing AWS.',
    author           = 'RunByKim',
    author_email     = 'runbykim@gmail.com',
    url              = 'https://github.com/runbykim/django-s3files.git',
    download_url     = 'https://github.com/runbykim/django-s3files.git',
    install_requires = ['boto3>=1.37.38'],
	include_package_data=True,
	packages         = find_packages(include=['s3files', 's3files.*']),
    package_data     = {'s3files': ['templates/*.html']},
    keywords         = ['django', 'aws', 's3', 'media', 'file', 'manager', 'django-storage'],
    python_requires  = '>=3',
    zip_safe         = False,
    classifiers      = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ]
)